aboutsummaryrefslogtreecommitdiff
path: root/internal/datasource.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/datasource.go')
-rw-r--r--internal/datasource.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/datasource.go b/internal/datasource.go
index 9782f139..db61d69e 100644
--- a/internal/datasource.go
+++ b/internal/datasource.go
@@ -50,10 +50,10 @@ type DataSource interface {
// LegacyGetModuleLicenses returns all top-level Licenses for the given modulePath
// and version. (i.e., Licenses contained in the module root directory)
LegacyGetModuleLicenses(ctx context.Context, modulePath, version string) ([]*licenses.License, error)
// GetPackage returns the LegacyVersionedPackage corresponding to the given package
// pkgPath, modulePath, and version. When multiple package paths satisfy this query, it
// should prefer the module with the longest path.
- GetPackage(ctx context.Context, pkgPath, modulePath, version string) (*LegacyVersionedPackage, error)
+ LegacyGetPackage(ctx context.Context, pkgPath, modulePath, version string) (*LegacyVersionedPackage, error)
// LegacyGetPackageLicenses returns all Licenses that apply to pkgPath, within the
// module version specified by modulePath and version.
LegacyGetPackageLicenses(ctx context.Context, pkgPath, modulePath, version string) ([]*licenses.License, error)
@@ -50,10 +50,10 @@ type DataSource interface {
// and version. (i.e., Licenses contained in the module root directory)
LegacyGetModuleLicenses(ctx context.Context, modulePath, version string) ([]*licenses.License, error)
- // GetPackage returns the LegacyVersionedPackage corresponding to the given package
+ // LegacyGetPackage returns the LegacyVersionedPackage corresponding to the given package
// pkgPath, modulePath, and version. When multiple package paths satisfy this query, it
// should prefer the module with the longest path.